@@ -1,8 +1,8 @@
 ;;; ai-code.el --- Unified interface for AI coding CLI such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, etc -*- lexical-binding: t; -*-
 
 ;; Author: Kang Tu <tninja@gmail.com>
-;; Package-Version: 20260209.1524
-;; Package-Revision: a5143fce3d8e
+;; Package-Version: 20260213.1730
+;; Package-Revision: c7767d6a9e6a
 ;; Package-Requires: ((emacs "28.1") (transient "0.8.0") (magit "2.1.0"))
 ;; URL: https://github.com/tninja/ai-code-interface.el
 
@@ -66,6 +66,10 @@
 (require 'transient)
 (require 'seq)
 
+(defgroup ai-code nil
+  "Unified interface for multiple AI coding CLIs."
+  :group 'tools)
+
 (require 'ai-code-backends)
 (require 'ai-code-backends-infra)
 (require 'ai-code-input)
@@ -294,7 +298,7 @@ Shows the current backend label to the right."
   ["AI Code Commands"
    ["AI CLI session"
     ("a" "Start AI CLI (C-u: args)" ai-code-cli-start)
-    ("R" "Resume AI CLI" ai-code-cli-resume)
+    ("R" "Resume AI CLI (C-u: args)" ai-code-cli-resume)
     ("z" "Switch to AI CLI (C-u: hide)" ai-code-cli-switch-to-buffer-or-hide)
     ;; Use plist style to provide a dynamic description function.
     ("s" ai-code-select-backend :description ai-code--select-backend-description)
@@ -321,7 +325,7 @@ Shows the current backend label to the right."
     ("v" "Pull or Review Code Change"  ai-code-pull-or-review-diff-file)
     ;; ("b" "Send prompt block to AI" ai-code-prompt-send-block)
     ("!" "Run Current File or Command" ai-code-run-current-file-or-shell-cmd)
-    ("b" "Build / Test project"               ai-code-build-or-test-project)
+    ("b" "Build / Test (AI follow-up)"   ai-code-build-or-test-project)
     ;; ("I" "Insert function name at point" ai-code-insert-function-at-point)
     ("K" "Create or open task file" ai-code-create-or-open-task-file)
     ("n" "Take notes from AI session region" ai-code-take-notes)
